summaryrefslogtreecommitdiffstats
path: root/lib/libalpm/alpm.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/libalpm/alpm.c')
-rw-r--r--lib/libalpm/alpm.c19
1 files changed, 16 insertions, 3 deletions
diff --git a/lib/libalpm/alpm.c b/lib/libalpm/alpm.c
index 37db1394..77f3632e 100644
--- a/lib/libalpm/alpm.c
+++ b/lib/libalpm/alpm.c
@@ -346,9 +346,9 @@ int alpm_db_update(int force, PM_DB *db)
pm_errno = 0;
return(1);
} else if(ret == -1) {
- /* we use fetchLastErrString and fetchLastErrCode here, error returns from
- * libfetch */
- _alpm_log(PM_LOG_DEBUG, _("failed to sync db: %s [%d]"), fetchLastErrString, fetchLastErrCode);
+ /* we use downloadLastErrString and downloadLastErrCode here, error returns from
+ * libdownload */
+ _alpm_log(PM_LOG_DEBUG, _("failed to sync db: %s [%d]"), downloadLastErrString, downloadLastErrCode);
RET_ERR(PM_ERR_DB_SYNC, -1);
} else {
if(strlen(newmtime)) {
@@ -1109,6 +1109,19 @@ int alpm_list_free(pmlist_t *entry)
return(0);
}
+/** Free the outer list, but not the contained data
+ * @param entry list to free
+ * @return 0 on success, -1 on error
+ */
+int alpm_list_free_outer(pmlist_t *entry)
+{
+ ASSERT(entry != NULL, return(-1));
+
+ _FREELIST(entry, NULL);
+
+ return(0);
+}
+
/** Count the entries in a list.
* @param list the list to count
* @return number of entries on success, NULL on error